# McCode Grammar files
Excluding `__init__.py`, the Python
contents of this folder are generated by `ANTLR`
from the grammar files, `McComp.g4` and `McInstr.g4`.

The (re)generation of the various language files
is done at import time of this (sub)module.
If the `Mc*.py` files have older modification times than the `Mc.g4` files,
then `ANTLR4` is called to reconstruct them.

As such, the generated files should not be edited by hand.
Instead, modify the grammar files, and possibly any
functions which make use of `Mc*Visitor` or `Mc*Listener`.
